/***********************************************************
 * $Id: AcceptMatcher.java 504 2011-06-16 07:13:04Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 16.06.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http;

/**
 * A matcher for items in <code>Accept</code>, <code>Accept-Charset</code>,
 * <code>Accept-Encoding</code> or <code>Accept-Language</code> HTTP headers.
 */
public interface AcceptMatcher {

	/**
	 * Match a server-provided item against a client-accepted item and
	 * return a match quality.
	 * 
	 * @param accepted An item as accepted by a client.
	 * @param provided An item as accepted by a server.
	 * @return A match quality. <code>1.0</code> means a perfect match,
	 *         <code>0.0</code> is returned for non-matching items.
	 *         Some matchers may return fuzzy matching like for locales.
	 */
	public double matchItem(String accepted, String provided);
}
